@@ -13,6 +13,7 @@ build_time_vars = {'ABIFLAGS': '',
  'BINLIBDEST': '/usr/lib/python3.8',
  'BLDLIBRARY': '-L. -lpython3.8',
  'BLDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro '
+              '-fno-semantic-interposition '
               '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -22,36 +23,38 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-           '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt',
+           '-fno-semantic-interposition -march=armv5te -O3 -pipe '
+           '-fstack-protector-strong -fno-plt -march=armv5te -O3 -pipe '
+           '-fstack-protector-strong -fno-plt',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-march=armv5te -O3 -pipe -fstack-protector-strong '
-                     '-fno-plt',
+                     '-fno-plt -fno-semantic-interposition',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-D_FORTIFY_SOURCE=2',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro '
+                      '-fno-semantic-interposition',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' "
-                "'--with-computed-gotos' '--without-lto' '--enable-ipv6' "
-                "'--with-system-expat' '--with-dbmliborder=gdbm:ndbm' "
-                "'--with-system-ffi' '--with-system-libmpdec' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
+                "'--without-lto' '--enable-ipv6' '--with-system-expat' "
+                "'--with-dbmliborder=gdbm:ndbm' '--with-system-ffi' "
+                "'--with-system-libmpdec' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'CFLAGS=-march=armv5te -O3 -pipe -fstack-protector-strong "
-                "-fno-plt' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' "
-                "'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+                "-fno-plt -fno-semantic-interposition' "
+                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro "
+                "-fno-semantic-interposition' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.8.0/coverage.info',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.8.0/lcov-report',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.8.3/coverage.info',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.8.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
@@ -417,7 +420,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
  'HAVE_STRLCPY': 0,
- 'HAVE_STROPTS_H': 1,
+ 'HAVE_STROPTS_H': 0,
  'HAVE_STRSIGNAL': 1,
  'HAVE_STRUCT_PASSWD_PW_GECOS': 1,
  'HAVE_STRUCT_PASSWD_PW_PASSWD': 1,
@@ -529,17 +532,19 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
  'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro '
+            '-fno-semantic-interposition '
             '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.8.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro '
+             '-fno-semantic-interposition '
              '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'LDVERSION': '3.8',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.8',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi-3.2.1/include',
+ 'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
@@ -623,13 +628,14 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -march=armv5te -O3 -pipe '
-                             '-fstack-protector-strong -fno-plt -march=armv5te '
-                             '-O3 -pipe -fstack-protector-strong -fno-plt '
+                             '-fstack-protector-strong -fno-plt '
+                             '-fno-semantic-interposition -march=armv5te -O3 '
+                             '-pipe -fstack-protector-strong -fno-plt '
                              '-march=armv5te -O3 -pipe '
                              '-fstack-protector-strong -fno-plt -std=c99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
@@ -640,8 +646,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt '
-              '-march=armv5te -O3 -pipe -fstack-protector-strong -fno-plt',
+              '-fno-semantic-interposition -march=armv5te -O3 -pipe '
+              '-fstack-protector-strong -fno-plt -march=armv5te -O3 -pipe '
+              '-fstack-protector-strong -fno-plt',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
@@ -649,29 +656,33 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -march=armv5te -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -march=armv5te -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -march=armv5te -O3 -pipe -fstack-protector-strong '
-                   '-fno-plt -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-fno-plt -fno-semantic-interposition -march=armv5te -O3 '
+                   '-pipe -fstack-protector-strong -fno-plt -march=armv5te -O3 '
+                   '-pipe -fstack-protector-strong -fno-plt -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -D_FORTIFY_SOURCE=2 '
                    '-D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro '
+                    '-fno-semantic-interposition '
                     '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'PY_CPPFLAGS': '-I. -I./Include -D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro '
+               '-fno-semantic-interposition '
                '-Wl,-O1,--sort-common,--as-needed,-z,relro',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv '
                         '-O3 -Wall -march=armv5te -O3 -pipe '
+                        '-fstack-protector-strong -fno-plt '
+                        '-fno-semantic-interposition -march=armv5te -O3 -pipe '
                         '-fstack-protector-strong -fno-plt -march=armv5te -O3 '
-                        '-pipe -fstack-protector-strong -fno-plt '
-                        '-march=armv5te -O3 -pipe -fstack-protector-strong '
-                        '-fno-plt -std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-pipe -fstack-protector-strong -fno-plt -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
                         '-I./Include/internal -I. -I./Include '
                         '-D_FORTIFY_SOURCE=2 -D_FORTIFY_SOURCE=2 -fPIC',
@@ -683,7 +694,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -725,9 +736,9 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0 ./python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.0 ./python '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.8.3 ./python '
                './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -735,10 +746,11 @@ build_time_vars = {'ABIFLAGS': '',
  'TM_IN_SYS_TIME': 0,
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3.8 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.8',
  'WINDOW_HAS_FLAGS': 1,
+ 'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 0,
@@ -748,8 +760,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.8.0',
- 'abs_srcdir': '/build/python/src/Python-3.8.0',
+ 'abs_builddir': '/build/python/src/Python-3.8.3',
+ 'abs_srcdir': '/build/python/src/Python-3.8.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
